#[non_exhaustive]pub struct DeleteWorkGroupInput {
pub work_group: Option<String>,
pub recursive_delete_option: Option<bool>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.work_group: Option<String>The unique name of the workgroup to delete.
recursive_delete_option: Option<bool>The option to delete the workgroup and its contents even if the workgroup contains any named queries, query executions, or notebooks.
Implementations
Sourceimpl DeleteWorkGroupInput
impl DeleteWorkGroupInput
Sourcepub fn work_group(&self) -> Option<&str>
pub fn work_group(&self) -> Option<&str>
The unique name of the workgroup to delete.
Sourcepub fn recursive_delete_option(&self) -> Option<bool>
pub fn recursive_delete_option(&self) -> Option<bool>
The option to delete the workgroup and its contents even if the workgroup contains any named queries, query executions, or notebooks.
Sourceimpl DeleteWorkGroupInput
impl DeleteWorkGroupInput
Sourcepub fn builder() -> DeleteWorkGroupInputBuilder
pub fn builder() -> DeleteWorkGroupInputBuilder
Creates a new builder-style object to manufacture DeleteWorkGroupInput.